@@ -38,6 +38,7 @@
 #include "intel_bufmgr.h"
 #include "intel_batchbuffer.h"
 #include "intel_gpu_tools.h"
+#include "igt_kms.h"
 
 #define MAX_CONNECTORS  10
 #define MAX_CRTCS       3
@@ -150,8 +151,6 @@ static int paint_fb(struct kmstest_fb *fb, const char *test_name,
 	int i;
 
 	cr = kmstest_get_cairo_ctx(drm_fd, fb);
-	if (!cr)
-		return -1;
 
 	kmstest_paint_test_pattern(cr, fb->width, fb->height);
 
@@ -175,6 +174,8 @@ static int paint_fb(struct kmstest_fb *fb, const char *test_name,
 					  crtc_str[i]);
 	}
 
+	cairo_destroy(cr);
+
 	return 0;
 }
 
@@ -274,6 +275,7 @@ static void setup_crtcs(drmModeRes *resources, struct connector_config *cconf,
 	int crtc_count;
 	bool config_valid;
 	int i;
+	int encoder_usage_count[resources->count_encoders];
 
 	i = 0;
 	crtc_count = 0;
@@ -336,6 +338,20 @@ static void setup_crtcs(drmModeRes *resources, struct connector_config *cconf,
 		crtc++;
 	}
 
+	memset(encoder_usage_count, 0, sizeof(encoder_usage_count));
+	for (i = 0; i < connector_count; i++) {
+		drmModeConnector *connector = cconf[i].connector;
+		drmModeEncoder *encoder;
+
+		igt_assert(connector->count_encoders == 1);
+		encoder = drmModeGetEncoder(drm_fd, connector->encoders[0]);
+		encoder_usage_count[get_encoder_idx(resources, encoder)]++;
+		drmModeFreeEncoder(encoder);
+	}
+	for (i = 0; i < resources->count_encoders; i++)
+		if (encoder_usage_count[i] > 1)
+			config_valid = false;
+
 	*crtc_count_ret = crtc_count;
 	*config_valid_ret = config_valid;
 }
@@ -674,6 +690,8 @@ int main(int argc, char **argv)
 		enum test_flags flags;
 		const char *name;
 	} tests[] = {
+		{ TEST_CLONE | TEST_SINGLE_CRTC_CLONE,
+					"clone-single-crtc" },
 		{ TEST_INVALID | TEST_CLONE | TEST_SINGLE_CRTC_CLONE,
 					"invalid-clone-single-crtc" },
 		{ TEST_INVALID | TEST_CLONE | TEST_EXCLUSIVE_CRTC_CLONE,
